@@ -8,15 +8,20 @@
 ------------------------------------------
 @Description:
 """
+import string
+
 from kgdt.models.graph import GraphData
 
+from sckg.buildtrie import Buildtrim
+
 
 class SoftwareKG:
-    def __init__(self, graph_path):
+    def __init__(self, graph_path, trie_path=None):
         self.graph: GraphData = GraphData.load(graph_path)
+        self.trie: Buildtrim = Buildtrim.load(trie_path)
 
     def is_exist_concept(self, word):
-        if self.graph.find_nodes_by_property("concept_name", word) is None:
+        if not self.graph.find_nodes_by_property("concept_name", word):
             return False
         return True
 
@@ -32,7 +37,7 @@ class SoftwareKG:
     def get_node_info_by_id(self, nodeid):
         return self.graph.get_node_info_dict(nodeid)
 
-    def get_concept_by_id(self,id):
+    def get_concept_by_id(self, id):
         return self.get_node_info_by_id(id)['properties']['concept_name']
 
     def get_node_by_concept(self, word):
@@ -142,3 +147,28 @@ class SoftwareKG:
                 if relation1[0] == relation2[0] and relation1[1] == relation2[1]:
                     comment_relations.append(self.get_concept_by_id(relation2[0]))
         return comment_relations
+
+    def find_include_prefix_concept(self, concept):
+        return self.trie.tree.items(prefix=concept)
+
+    def find_all_concept_from_sentence(self, sentence):
+        # 给一段文本，返回在KG里面出现的概念
+        concepts = []
+        sentence = sentence.lower()
+        sentence = sentence.translate(str.maketrans('', '', string.punctuation))
+        words = sentence.strip("\n").lower().split()
+        for i, word in enumerate(words):
+            concept = word
+            if i == len(words) - 1:
+                break
+            for j in range(i + 1, i + 5):
+                if j < len(words):
+                    concept = concept + " " + words[j]
+                if self.is_exist_concept(concept):
+                    concepts.append(concept)
+        for word in words:
+            if not self.is_exist_concept(word):
+                continue
+            concepts.append(word)
+        concepts = set(concepts)
+        return concepts
